## Insert

### ::: pyflp.insert.insert.Insert
    selection:
      members:
        - EventID
        - color
        - enabled
        - eq
        - flags
        - icon
        - input
        - locked
        - name
        - output
        - pan
        - route_volumes
        - routing
        - slots
        - stereo_separation
        - volume

## InsertSlot

### ::: pyflp.insert.slot.InsertSlot
    selection:
      members:
        - EventID
        - default_name
        - enabled
        - icon
        - index
        - mix
        - name
        - new
        - plugin
        - is_used
